
# Slot: location of


holds between material entity or site and a material entity that is located within it (but not considered a part of it)

URI: [biolink:location_of](https://w3id.org/biolink/vocab/location_of)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0001015 |
|  | | SEMMEDDB:LOCATION_OF |
|  | | SEMMEDDB:location_of |
|  | | WIKIDATA_PROPERTY:P276 |
|  | | FMA:location_of |
|  | | RTXKG1:site_of |
| **Narrow Mappings:** | | SNOMED:inherent_location_of |

